@@ -2,4 +2,4 @@ mod article;
 mod html;
 mod rcdom;
 
-pub use {article::*, html::*};
+pub use html::*;
